
/* Chrysalide - Outil d'analyse de fichiers binaires
 * core.c - mise à disposition d'un support Kaitai pour ROST
 *
 * Copyright (C) 2023 Cyrille Bagard
 *
 *  This file is part of Chrysalide.
 *
 *  Chrysalide is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Chrysalide is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Chrysalide.  If not, see <http://www.gnu.org/licenses/>.
 */


#include "core.h"


#include <core/global.h>


#include "space.h"



/******************************************************************************
*                                                                             *
*  Paramètres  : -                                                            *
*                                                                             *
*  Description : Intègre un support de Kaitai pour ROST.                      *
*                                                                             *
*  Retour      : Bilan du chargement mené.                                    *
*                                                                             *
*  Remarques   : -                                                            *
*                                                                             *
******************************************************************************/

bool add_kaitai_support_to_rost(void)
{
    bool result;                            /* Bilan à retourner           */
    GScanNamespace *root_ns;                /* Espace de noms ROST racine  */
    GScanNamespace *kaitai_ns;              /* Espace de noms pour Kaitai  */

    result = true;

    root_ns = get_rost_root_namespace();

    kaitai_ns = g_kaitai_namespace_new();

    result = g_scan_namespace_register_item(root_ns, G_SCAN_REGISTERED_ITEM(kaitai_ns));

    g_object_unref(G_OBJECT(kaitai_ns));

    g_object_unref(G_OBJECT(root_ns));

    return result;

}
